summaryrefslogtreecommitdiffstats
path: root/include/clang/Sema/CodeCompleteConsumer.h
diff options
context:
space:
mode:
authorDouglas Gregor <dgregor@apple.com>2011-07-30 06:55:39 +0000
committerDouglas Gregor <dgregor@apple.com>2011-07-30 06:55:39 +0000
commit0f91c8ccb398be2bd40dc402309bd79737542396 (patch)
treee2302113b706b7d2e79baf1b2ffaa5218ae011d0 /include/clang/Sema/CodeCompleteConsumer.h
parent4eb7522e70a7212328089f0ef490380a9ba322a3 (diff)
When performing code completion after at @interface, allow both
already-defined and forward-declared results. Already-defined results are fine because they could be the start of a category. Fixes <rdar://problem/9811691>. git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@136559 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/clang/Sema/CodeCompleteConsumer.h')
-rw-r--r--include/clang/Sema/CodeCompleteConsumer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/clang/Sema/CodeCompleteConsumer.h b/include/clang/Sema/CodeCompleteConsumer.h
index 8c7a00280b..2213c7c7e6 100644
--- a/include/clang/Sema/CodeCompleteConsumer.h
+++ b/include/clang/Sema/CodeCompleteConsumer.h
@@ -248,9 +248,9 @@ public:
CCC_ObjCInstanceMessage,
/// \brief Code completion where an Objective-C class message is expected.
CCC_ObjCClassMessage,
/// \brief Code completion where a superclass of an Objective-C class is
/// expected.
- CCC_ObjCSuperclass,
+ CCC_ObjCInterfaceName,
/// \brief Code completion where an Objective-C category name is expected.
CCC_ObjCCategoryName,
/// \brief An unknown context, in which we are recovering from a parsing
@@ -248,9 +248,9 @@ public:
/// \brief Code completion where an Objective-C class message is expected.
CCC_ObjCClassMessage,
- /// \brief Code completion where a superclass of an Objective-C class is
+ /// \brief Code completion where the name of an Objective-C class is
/// expected.